import { Buffer } from 'node:buffer';

var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
var __accessCheck = (obj, member, msg) => {
  if (!member.has(obj))
    throw TypeError("Cannot " + msg);
};
var __privateGet = (obj, member, getter) => {
  __accessCheck(obj, member, "read from private field");
  return getter ? getter.call(obj) : member.get(obj);
};
var __privateAdd = (obj, member, value) => {
  if (member.has(obj))
    throw TypeError("Cannot add the same private member more than once");
  member instanceof WeakSet ? member.add(obj) : member.set(obj, value);
};
var __privateSet = (obj, member, value, setter) => {
  __accessCheck(obj, member, "write to private field");
  setter ? setter.call(obj, value) : member.set(obj, value);
  return value;
};
var __privateMethod = (obj, member, method) => {
  __accessCheck(obj, member, "access private method");
  return method;
};
var _BloomFilter = class _BloomFilter {
  constructor(size) {
    this.size = size;
    this.bitArray = new Uint8Array(Math.ceil(size / 8));
  }
  add(item) {
    const index = murmurHash3(item) % this.size;
    this.bitArray[Math.floor(index / 8)] |= 1 << index % 8;
  }
  test(item) {
    const index = murmurHash3(item) % this.size;
    return (this.bitArray[Math.floor(index / 8)] & 1 << index % 8) !== 0;
  }
  // Serialize to a Base64 string
  serialize() {
    return Buffer.from(this.bitArray).toString("base64");
  }
  // Deserialize from a Base64 string
  static deserialize(str, size) {
    const filter = new _BloomFilter(size);
    filter.bitArray = Uint8Array.from(Buffer.from(str, "base64"));
    return filter;
  }
};
__name(_BloomFilter, "BloomFilter");
__publicField(_BloomFilter, "NOOP_TASK_SET_SIZE", 32768);
var BloomFilter = _BloomFilter;
function murmurHash3(str, seed = 0) {
  let h1 = 3735928559 ^ seed, h2 = 1103547991 ^ seed;
  for (let i = 0, ch; i < str.length; i++) {
    ch = str.charCodeAt(i);
    h1 = Math.imul(h1 ^ ch, 3432918353);
    h1 = h1 << 15 | h1 >>> 17;
    h1 = Math.imul(h1, 461845907);
    h2 = Math.imul(h2 ^ ch, 2246822507);
    h2 = h2 << 13 | h2 >>> 19;
    h2 = Math.imul(h2, 3266489909);
  }
  h1 ^= str.length;
  h2 ^= str.length;
  h1 = Math.imul(h1 ^ h1 >>> 16, 2246822507);
  h1 = Math.imul(h1 ^ h1 >>> 13, 3266489909);
  h1 ^= h1 >>> 16;
  h2 = Math.imul(h2 ^ h2 >>> 16, 2246822507);
  h2 = Math.imul(h2 ^ h2 >>> 13, 3266489909);
  h2 ^= h2 >>> 16;
  return 4294967296 * (2097151 & h2) + (h1 >>> 0);
}
__name(murmurHash3, "murmurHash3");
var env = process.env;
var logLevels = [
  "log",
  "error",
  "warn",
  "info",
  "debug"
];
var _name, _level, _filteredKeys, _jsonReplacer, _additionalFields, _structuredLog, structuredLog_fn;
var _Logger = class _Logger {
  constructor(name, level = "info", filteredKeys = [], jsonReplacer, additionalFields) {
    __privateAdd(this, _structuredLog);
    __privateAdd(this, _name, void 0);
    __privateAdd(this, _level, void 0);
    __privateAdd(this, _filteredKeys, []);
    __privateAdd(this, _jsonReplacer, void 0);
    __privateAdd(this, _additionalFields, void 0);
    __privateSet(this, _name, name);
    __privateSet(this, _level, logLevels.indexOf(env.TRIGGER_LOG_LEVEL ?? level));
    __privateSet(this, _filteredKeys, filteredKeys);
    __privateSet(this, _jsonReplacer, createReplacer(jsonReplacer));
    __privateSet(this, _additionalFields, additionalFields ?? (() => ({})));
  }
  // Return a new Logger instance with the same name and a new log level
  // but filter out the keys from the log messages (at any level)
  filter(...keys) {
    return new _Logger(__privateGet(this, _name), logLevels[__privateGet(this, _level)], keys, __privateGet(this, _jsonReplacer));
  }
  static satisfiesLogLevel(logLevel, setLevel) {
    return logLevels.indexOf(logLevel) <= logLevels.indexOf(setLevel);
  }
  log(message, ...args) {
    if (__privateGet(this, _level) < 0)
      return;
    __privateMethod(this, _structuredLog, structuredLog_fn).call(this, console.log, message, "log", ...args);
  }
  error(message, ...args) {
    if (__privateGet(this, _level) < 1)
      return;
    __privateMethod(this, _structuredLog, structuredLog_fn).call(this, console.error, message, "error", ...args);
  }
  warn(message, ...args) {
    if (__privateGet(this, _level) < 2)
      return;
    __privateMethod(this, _structuredLog, structuredLog_fn).call(this, console.warn, message, "warn", ...args);
  }
  info(message, ...args) {
    if (__privateGet(this, _level) < 3)
      return;
    __privateMethod(this, _structuredLog, structuredLog_fn).call(this, console.info, message, "info", ...args);
  }
  debug(message, ...args) {
    if (__privateGet(this, _level) < 4)
      return;
    __privateMethod(this, _structuredLog, structuredLog_fn).call(this, console.debug, message, "debug", ...args);
  }
};
_name = new WeakMap();
_level = new WeakMap();
_filteredKeys = new WeakMap();
_jsonReplacer = new WeakMap();
_additionalFields = new WeakMap();
_structuredLog = new WeakSet();
structuredLog_fn = /* @__PURE__ */ __name(function(loggerFunction, message, level, ...args) {
  const structuredLog = {
    ...structureArgs(safeJsonClone(args), __privateGet(this, _filteredKeys)),
    ...__privateGet(this, _additionalFields).call(this),
    timestamp: /* @__PURE__ */ new Date(),
    name: __privateGet(this, _name),
    message,
    level
  };
  loggerFunction(JSON.stringify(structuredLog, __privateGet(this, _jsonReplacer)));
}, "#structuredLog");
__name(_Logger, "Logger");
var Logger = _Logger;
function createReplacer(replacer) {
  return (key, value) => {
    if (typeof value === "bigint") {
      return value.toString();
    }
    if (replacer) {
      return replacer(key, value);
    }
    return value;
  };
}
__name(createReplacer, "createReplacer");
function bigIntReplacer(_key, value) {
  if (typeof value === "bigint") {
    return value.toString();
  }
  return value;
}
__name(bigIntReplacer, "bigIntReplacer");
function safeJsonClone(obj) {
  try {
    return JSON.parse(JSON.stringify(obj, bigIntReplacer));
  } catch (e) {
    return;
  }
}
__name(safeJsonClone, "safeJsonClone");
function structureArgs(args, filteredKeys = []) {
  if (!args) {
    return;
  }
  if (args.length === 0) {
    return;
  }
  if (args.length === 1 && typeof args[0] === "object") {
    return filterKeys(JSON.parse(JSON.stringify(args[0], bigIntReplacer)), filteredKeys);
  }
  return args;
}
__name(structureArgs, "structureArgs");
function filterKeys(obj, keys) {
  if (typeof obj !== "object" || obj === null) {
    return obj;
  }
  if (Array.isArray(obj)) {
    return obj.map((item) => filterKeys(item, keys));
  }
  const filteredObj = {};
  for (const [key, value] of Object.entries(obj)) {
    if (keys.includes(key)) {
      if (value) {
        filteredObj[key] = `[filtered ${prettyPrintBytes(value)}]`;
      } else {
        filteredObj[key] = value;
      }
      continue;
    }
    filteredObj[key] = filterKeys(value, keys);
  }
  return filteredObj;
}
__name(filterKeys, "filterKeys");
function prettyPrintBytes(value) {
  if (env.NODE_ENV === "production") {
    return "skipped size";
  }
  const sizeInBytes = getSizeInBytes(value);
  if (sizeInBytes < 1024) {
    return `${sizeInBytes} bytes`;
  }
  if (sizeInBytes < 1024 * 1024) {
    return `${(sizeInBytes / 1024).toFixed(2)} KB`;
  }
  if (sizeInBytes < 1024 * 1024 * 1024) {
    return `${(sizeInBytes / (1024 * 1024)).toFixed(2)} MB`;
  }
  return `${(sizeInBytes / (1024 * 1024 * 1024)).toFixed(2)} GB`;
}
__name(prettyPrintBytes, "prettyPrintBytes");
function getSizeInBytes(value) {
  const jsonString = JSON.stringify(value);
  return Buffer.byteLength(jsonString, "utf8");
}
__name(getSizeInBytes, "getSizeInBytes");

export { BloomFilter, Logger };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.mjs.map